@@ -104,7 +104,7 @@ bool DummyCommandPlugin::command(QString command, QList<QString> params)
     return true;
 }
 
-#ifndef QT5
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 Q_EXPORT_PLUGIN2(dummycommandplugin, DummyCommandPlugin)
 #endif
 
