@@ -84,7 +84,7 @@ bool DummyDecoderPlugin::decodeMsg(QDltMsg &msg, int triggeredByUser)
     return false;
 }
 
-#ifndef QT5
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 Q_EXPORT_PLUGIN2(dummydecoderplugin, DummyDecoderPlugin);
 #endif
 
