@@ -110,10 +110,6 @@ bool FiletransferPlugin::loadConfig(QString filename)
               {
                   config.setFlerTag( xml.readElementText() );
               }
-              if(xml.name() == QString("TAG_FLCTID"))
-              {
-                  config.setFlCtIdTag( xml.readElementText() );
-              }
               if(xml.name() == QString("AUTOSAVE"))
               {
                   config.setAutoSavePath( xml.readElementText() );
@@ -169,7 +165,6 @@ QStringList FiletransferPlugin::infoConfig()
 {
     QStringList list;
 
-    list.append("TAG_FLCTID: "+ config.getFlCtIdTag());
     list.append("TAG_FLST: "+ config.getFlstTag());
     list.append("TAG_FLDA: "+ config.getFldaTag());
     list.append("TAG_FLFI: "+ config.getFlfiTag());
@@ -262,13 +257,6 @@ void FiletransferPlugin::updateFiletransfer(int index, QDltMsg &msg)
         return;
     }
 
-
-    if(config.getFlCtIdTag()!=msg.getCtid())
-    {
-        // message is not of CTID defined to indicate file transfer
-        return;
-    }
-
     if(!msg.getArgument(PROTOCOL_ALL_STARTFLAG,msgFirstArgument))
     {
         return;
