@@ -29,12 +29,6 @@ public:
     */
     int size() const;
 
-    //! The number of plugins that are enabled
-    /*!
-      \return the number of loaded plugins and enabled.
-    */
-    int sizeEnabled() const;
-
     //! Loads all plugins from three directories.current working sub directory /plugin
     /*!
       The three directories:
@@ -86,7 +80,7 @@ public:
     void initPluginPriority(const QStringList &desiredPrio);
     bool decreasePluginPriority(const QString &name);
     bool raisePluginPriority(const QString &name);
-    bool setPluginPriority(const QString name, unsigned int prio);
+    bool setPluginPriority(const QString& name, int prio);
     QStringList getPluginPriorities() const;
 
 private:
