@@ -382,10 +382,10 @@ private:
     void writeDLTMessageToFile(QByteArray &bufferHeader,char*bufferPayload,quint32 bufferPayloadSize,EcuItem* ecuitem,quint32 sec=0,quint32 use=0);
 
 protected:
-    void keyPressEvent ( QKeyEvent * event );
-    void dragEnterEvent(QDragEnterEvent *event);
-    void dropEvent(QDropEvent *event);
-    void closeEvent(QCloseEvent *event);
+    void keyPressEvent ( QKeyEvent * event ) override;
+    void dragEnterEvent(QDragEnterEvent *event) override;
+    void dropEvent(QDropEvent *event) override;
+    void closeEvent(QCloseEvent *event) override;
 
 private slots:
     void reloadLogFileProgressMax(int num);
@@ -609,6 +609,9 @@ public slots:
     void onAddActionToHistory();
     void onSearchProgressChanged(bool isInProgress);
 
+    void handleImportResults(const QString &);
+    void handleExportResults(const QString &);
+
 public:
 
     /* Project configuration containing ECU/APP/Context/Filter/Plugin configuration */
